@@ -1,4 +1,4 @@
-//$Id: blob-res.h,v 1.1 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: blob-res.h,v 1.2 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,10 +28,14 @@ namespace Guikachu
 }
 
 #include "resource.h"
-#include "blob-win.h"
 
 namespace Guikachu
 {
+    namespace GUI
+    {
+	class BlobWindow;
+    }
+    
     namespace Resources
     {
 	class Blob: public Resource
