@@ -1,4 +1,4 @@
-//$Id: dialog-res.cc,v 1.14 2001/10/09 16:37:12 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.cc,v 1.15 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -17,8 +17,7 @@
  */
 
 #include "dialog-res.h"
-
-#include <gnome-xml/xmlmemory.h>
+#include "dialog-win.h"
 
 using namespace Guikachu;
 
