@@ -1,4 +1,4 @@
-//$Id: dialog-res.h,v 1.7 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.h,v 1.8 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,12 +38,16 @@ namespace Guikachu
 
 #include "resource.h"
 #include "resource-ref.h"
-#include "dialog-win.h"
 
 #include <vector>
 
 namespace Guikachu
 {
+    namespace GUI
+    {
+	class DialogWindow;
+    }
+    
     namespace Resources
     {
 	class Dialog: public Resource
