@@ -1,4 +1,4 @@
-//$Id: dialog-win.h,v 1.9 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.h,v 1.10 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,14 +30,7 @@ namespace Guikachu
 #include "dialog-res.h"
 
 #include <gtk--/window.h>
-#include <gtk--/entry.h>
-#include <gtk--/text.h>
 #include <gtk--/optionmenu.h>
-#include <gtk--/button.h>
-#include <gtk--/list.h>
-#include "widgets/resource-combo.h"
-
-#include <glade/glade-xml.h>
 
 namespace Guikachu
 {
@@ -47,39 +40,32 @@ namespace Guikachu
 	{
 	    Resources::Dialog   *res;
 	    
-	    GladeXML            *gui;
-	    Gtk::Window         *window;
+	    Gtk::Window          window;
 	    
-	    Gtk::Entry          *id_entry;
-	    Gtk::Entry          *title_entry;
-	    Gtk::Text           *text_entry;
-	    Gtk::OptionMenu     *type_combo;
-	    GUI::ResourceCombo   help_combo;
+	    Gtk::OptionMenu      type_combo;
 	    
-	    Gtk::List           *button_list;
-	    Gtk::Button         *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
+//	    Gtk::List           *button_list;
+//	    Gtk::Button         *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
 	public:
 	    DialogWindow (Resources::Dialog *res_);
-	    ~DialogWindow ();
 	    void show ();
 	private:
 	    int delete_event_impl (GdkEventAny *e);
 	    void update ();
 
-	    void id_entry_cb ();
-	    void title_entry_cb ();
-	    void text_entry_cb ();
 	    void type_menu_cb (Resources::DialogType type);
 	    bool update_block;
 
+#if 0
 	    void button_add_cb ();
 	    void button_remove_cb ();
 	    void button_default_cb ();
 	    void button_up_cb ();
 	    void button_down_cb ();
 	    void button_sel_change_cb ();
-
+	    
 	    void dialog_add_cb (string name);
+#endif
 	};
     };
 };
