@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.23 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.25 2001/10/31 23:02:10 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -227,11 +227,17 @@ void Button::save_rcp (ostream &ostr) const
 int Button::get_auto_width ()
 {
     int text_width = get_string_width (font, text);
-    return 2 + text_width + 2;
+    return 6 + text_width + 6;
 }
 
 int Button::get_auto_height ()
 {
     int text_height = get_font_height (font);
-    return text_height + 2;
+
+    if (frame == BUTTON_FRAME_SIMPLE)
+	text_height += 2;
+    if (frame == BUTTON_FRAME_BOLD)
+	text_height += 1;
+	
+    return text_height;
 }
