@@ -1,4 +1,4 @@
-//$Id: canvasitem.cc,v 1.15 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.16 2001/10/27 13:29:26 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -75,11 +75,16 @@ void CanvasItem::set_canvas_item (Gnome::CanvasGroup *item_)
 
 int CanvasItem::canvas_event_cb (GdkEvent *e)
 {
-    /*
-    if (drag_context.dragging)
-	cerr << "canvas_event_cb" << endl;
-    */
-	
+    // Single click
+    if ((e->type == GDK_BUTTON_PRESS) &&
+	(e->button.button == 1))
+	clicked ();
+
+    // Context menu
+    if ((e->type == GDK_BUTTON_PRESS) &&
+	(e->button.button == 3))
+	popup_menu.popup (e->button.button, e->button.time);
+    
     // Begin drag
     if (e->type == GDK_BUTTON_PRESS &&
 	e->button.button == 1 &&
@@ -97,18 +102,6 @@ int CanvasItem::canvas_event_cb (GdkEvent *e)
 	drag_context.dragging)
 	drag_end_impl (e);
     
-
-    // Single click
-    if ((e->type == GDK_BUTTON_PRESS) &&
-	(e->button.button == 1))
-	clicked ();
-    
-
-    // Context menu
-    if ((e->type == GDK_BUTTON_PRESS) &&
-	(e->button.button == 3))
-	popup_menu.popup (e->button.button, e->button.time);
-    
     return TRUE;
 }
 
@@ -125,11 +118,12 @@ void CanvasItem::drag_begin_impl (GdkEvent *e)
 
     drag_context.delta_remainder_x = 0;
     drag_context.delta_remainder_y = 0;
-    
-    Gdk_Cursor cursor (gdk_cursor_new (GDK_FLEUR));
+
+    Gdk_Cursor cursor (GDK_FLEUR);
     item->grab (GDK_POINTER_MOTION_MASK | GDK_BUTTON_MOTION_MASK |
 		GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK,
 		cursor, e->button.time);
+    cursor.destroy ();
 
     drag_begin.emit ();
 }
