@@ -1,4 +1,4 @@
-//$Id: font.cc,v 1.4 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
+//$Id: font.cc,v 1.5 2001/10/25 21:30:32 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -112,6 +112,12 @@ void Font::parse (istream &stream)
     }
 }
 
+static void free_pixdata_delete (guchar *pixels, gpointer data)
+{
+    delete pixels;
+}
+
+
 GdkPixbuf* Font::render (const string    &text,
 			 const Gdk_Color &color) const
 {
@@ -171,7 +177,7 @@ GdkPixbuf* Font::render (const string    &text,
 				     8,
 				     width, height,
 				     width * 4,
-				     0, 0);
+				     free_pixdata_delete, 0);
 }
 
 unsigned int Font::string_width (const string &text) const
