@@ -1,4 +1,4 @@
-//$Id: font.h,v 1.2 2001/07/05 22:25:14 cactus Exp $ -*- c++ -*-
+//$Id: font.h,v 1.3 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,18 +44,22 @@ namespace Guikachu
 	    class Font
 	    {
 		hash_map <char, Glyph> glyphs;
-		unsigned int          height;
+		unsigned int           height, ascent, descent;
 		
 	    public:
 		Font (const string &filename);
 		Font ();
 
-		void parse (const string& filename);
-		void parse (istream &stream);
+		void parse (const string &filename);
+		void parse (istream      &stream);
 
 		GdkPixbuf* render (const string    &text,
 				   const Gdk_Color &color) const;
 		unsigned int string_width (const string& text) const;
+		
+		int get_height  () const { return height; };
+		int get_ascent  () const { return ascent; };
+		int get_descent () const { return descent; };
 	    };
 	}
     }
