@@ -1,4 +1,4 @@
-//$Id: graffiti.h,v 1.5 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.h,v 1.6 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,11 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_GRAFITI_H
 #define GUIKACHU_FORM_EDITOR_GRAFITI_H
 
-#include <string>
-#include <iostream>
-#include "widget.h"
-#include "resource.h"
-
 namespace Guikachu
 {
     namespace Widgets
@@ -32,6 +27,8 @@ namespace Guikachu
     }
 }
 
+#include "widget.h"
+
 #include "graffiti-prop.h"
 
 namespace Guikachu
