@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.10 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.12 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,7 +32,7 @@ PopupTrigger::PopupTrigger (Resources::Form *owner,
     Resizeable (changed),
     Textual (changed, id),
     editor (0),
-    list_id (changed, ""),
+    list_id (changed, owner),
     usable (changed, true),
     anchor_right (changed, false)
 {
@@ -185,7 +185,7 @@ void PopupTrigger::save_rcp (ostream &ostr) const
 
 int PopupTrigger::get_auto_width ()
 {
-    return get_string_width (font, text);
+    return get_string_width (font, text) + 16;
 }
 
 int PopupTrigger::get_auto_height ()
