@@ -1,4 +1,4 @@
-//$Id: pushbutton.cc,v 1.12 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.cc,v 1.13 2001/10/26 20:46:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -175,7 +175,7 @@ int PushButton::get_auto_width ()
 {
     int text_width = get_string_width (font, text);
 
-    return 2 + text_width + 2;
+    return text_width + 6;
 }
 
 int PushButton::get_auto_height ()
