@@ -1,4 +1,4 @@
-//$Id: scrollbar.cc,v 1.10 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.11 2001/10/26 20:46:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -160,7 +160,7 @@ void ScrollBar::save (StorageNode &node) const
     /* Values */
     my_node = node.add_node ("values");
     my_node.set_prop ("min",       min_value);
-    my_node.set_prop ("max",       min_value);
+    my_node.set_prop ("max",       max_value);
     my_node.set_prop ("page_size", page_size);
     my_node.set_prop ("value",     value);
 }
