@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.11 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.12 2001/10/26 20:46:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -177,7 +177,7 @@ void SelectorTrigger::save_rcp (ostream &ostr) const
 int SelectorTrigger::get_auto_width ()
 {
     int text_width = get_string_width (font, text);
-    return 2 + text_width + 2;
+    return 6 + text_width;
 }
 
 int SelectorTrigger::get_auto_height ()
