@@ -1,4 +1,4 @@
-//$Id: table-prop.cc,v 1.3 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-
+//$Id: table-prop.cc,v 1.4 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -107,8 +107,7 @@ TableProperties::TableProperties (Table *res)
 					_("Columns")));
 
     notebook->show_all ();
-    property_editor = manage (notebook);
-    gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+    property_editor = notebook;
 }
 
 TableProperties::~TableProperties ()
