@@ -1,4 +1,4 @@
-//$Id: widget-util.h,v 1.1 2001/09/19 16:23:39 cactus Exp $ -*- c++ -*-
+//$Id: widget-util.h,v 1.2 2001/10/16 16:11:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,15 +21,17 @@
 
 #include <string>
 #include "widget.h"
+#include <glib.h>
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	string type_id_from_type       (Type          type);
-	Type   type_from_type_id       (const string &type_id);
-	
-	const char * const * type_icon (Type          type);
+	const string type_id_from_type       (Type          type)    G_GNUC_CONST;
+	Type         type_from_type_id       (const string &type_id);
+
+	const string display_name_from_type  (Type          type)    G_GNUC_CONST;
+	const char * const * type_icon       (Type          type)    G_GNUC_CONST;
     }
 }
 
