@@ -1,4 +1,4 @@
-//$Id: widget.h,v 1.25 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.26 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,7 +36,8 @@ namespace Guikachu
 	    WIDGET_POPUP_TRIGGER,
 	    WIDGET_SCROLLBAR,
 	    WIDGET_TEXT_FIELD,
-	    WIDGET_TABLE
+	    WIDGET_TABLE,
+	    WIDGET_GADGET
 	};
 
 	class Widget;
