@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.15 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.16 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,7 +29,6 @@ namespace Guikachu
 
 #include "resource.h"
 #include "resource-ref.h"
-#include "form-win.h"
 #include "form-editor/widget.h"
 #include "form-editor/widget-ref.h"
 
@@ -37,6 +36,11 @@ namespace Guikachu
 
 namespace Guikachu
 {
+    namespace GUI
+    {
+	class FormWindow;
+    }
+    
     namespace Resources
     {
 	class Form: public Resource
