@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.9 2001/08/12 23:24:15 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.11 2001/11/04 18:55:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,35 +19,33 @@
 #include "config.h"
 
 #include <gnome--/main.h>
+#include <glade/glade.h>
+
+#include <fcntl.h>
 
 #ifdef USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
-#include <glade/glade.h>
-#include <fcntl.h>
-
 #include "mainwin.h"
 #include "resource-manager.h"
+#include "session.h"
 
-namespace Guikachu
-{
+namespace {
     enum FileType
     {
 	FILETYPE_REGULAR,
 	FILETYPE_GLADE,
 	FILETYPE_FONT
     };
-
+    
     struct FileEntry
     {
 	const char *filename;
 	FileType type;
     };
 }
-
-using namespace Guikachu;
-
+    
 static bool check_file (FileEntry& file)
 {
     bool success = true;
@@ -108,14 +106,14 @@ static bool check_files ()
     {
 	if (!check_file (files[i]))
 	{
-	    success = false;
 	    gchar *buffer = g_strdup_printf (
 		_("Opening file `%s' (required by Guikachu) failed.\n"
 		  "Check your Guikachu installation"),
 		g_basename (files[i].filename));
-	    
-	    GUI::show_error (buffer);
+	    Guikachu::GUI::show_error (buffer);
 	    g_free (buffer);
+	    
+	    success = false;
 	}
     }
 
@@ -129,32 +127,45 @@ int main (int argc, char **argv)
     textdomain (PACKAGE);
 #endif
 
-    poptContext ctx;
-    Gnome::Main m (PACKAGE, VERSION, argc, argv, NULL, 0, &ctx);
-    glade_gnome_init ();
-
+    using namespace Guikachu;
+    
+    Main app (argc, argv);
+    
     if (!check_files ())
 	return -1;
 
 #ifdef USE_WM_ICONS
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/guikachu.png");
-#endif    
-
-    ResourceManager::reset ();
-    GUI::MainWin w;
-
-    const char **args = poptGetArgs (ctx);
-    string filename;
-    if (args)
-    {
-	for (; *args; args++)
-	    filename = *args;
-	
-	ResourceManager::load (filename);
-	w.set_filename (filename);
-    }
-    poptFreeContext (ctx);
+#endif
     
-    w.show_all ();
-    m.run ();
+    GUI::MainWin main_win;
+    
+    const vector<string> &filenames = app.get_cmd_arguments ();
+    string filename = "";
+
+    if (filenames.size ())
+    {
+	for (vector<string>::const_iterator i = filenames.begin ();
+	     i != filenames.end (); i++)
+	    filename = *i;
+	    
+	ResourceManager::IOResult result = ResourceManager::load (filename);
+	if (result == ResourceManager::IO_INVALID)
+	{
+	    gchar *buffer = g_strdup_printf (_("Unable to open `%s': "
+					       "Not a valid Guikachu document"),
+					     g_basename (filename.c_str ()));
+	    GUI::show_error (buffer);
+	    g_free (buffer);
+	    ResourceManager::reset ();
+	    
+	} else {
+
+	    app.set_filename (filename);
+	    main_win.set_filename (filename);
+	}
+    }
+
+    main_win.show_all ();
+    app.run ();
 }
