@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.7 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.9 2001/11/04 18:55:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,7 @@
 #include "mainwin.h"
 
 #include "resource-manager.h"
+#include "session.h"
 #include <gnome--/main.h>
 
 using namespace Guikachu;
@@ -59,7 +60,7 @@ bool GUI::MainWin::check_save ()
 	if (in_exit)
 	    Gnome::Main::quit ();
     
-    if (response == 0) // OK
+    if (response == 0) // Yes
 	save_cb ();
     
     return true;
@@ -73,6 +74,7 @@ void GUI::MainWin::new_cb ()
 
     ResourceManager::reset ();
     filename = "";
+    Guikachu::Main::instance ()->set_filename (filename);
 
     update_title ();
 }
@@ -164,7 +166,7 @@ void GUI::MainWin::filesel_save_cb (Gtk::FileSelection *fs)
 {
     filename = fs->get_filename ();
     filesel_close_cb (fs);
-
+    Guikachu::Main::instance ()->set_filename (filename);
 
     update_title ();
     save_cb ();
@@ -178,10 +180,29 @@ void GUI::MainWin::filesel_open_cb (Gtk::FileSelection *fs)
     string new_filename = fs->get_filename ();
     filesel_close_cb (fs);
 
-    if (ResourceManager::load (new_filename))
+    ResourceManager::IOResult result = ResourceManager::load (new_filename);
+
+    gchar *buffer;
+    switch (result)
     {
+    case ResourceManager::IO_OK:
 	filename = new_filename;
+	Guikachu::Main::instance ()->set_filename (filename);
 	update_title ();
+	break;
+    case ResourceManager::IO_NOTFOUND:
+	buffer = g_strdup_printf (_("Unable to open `%s'"),
+				  g_basename (new_filename.c_str ()));
+	GUI::show_error (buffer);
+	g_free (buffer);
+	break;
+    case ResourceManager::IO_INVALID:
+	buffer = g_strdup_printf (_("Unable to open `%s': "
+				    "Not a valid Guikachu document"),
+				  g_basename (new_filename.c_str ()));
+	GUI::show_error (buffer);
+	g_free (buffer);
+	break;
     }
 }
 
