@@ -1,4 +1,4 @@
-//$Id: menu-res.h,v 1.5 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.h,v 1.6 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,12 +30,16 @@ namespace Guikachu
 }
 
 #include "resource.h"
-#include "menu-win.h"
 
 #include <vector>
 
 namespace Guikachu
 {
+    namespace GUI
+    {
+	class MenuWindow;
+    }
+    
     namespace Resources
     {
 	struct MenuItem
