@@ -1,4 +1,4 @@
-//$Id: property.cc,v 1.3 2001/10/20 16:06:50 cactus Exp $ -*- c++ -*-
+//$Id: property.cc,v 1.5 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -17,7 +17,6 @@
  */
 
 #include "property.h"
-
 #include "resource-manager.h"
 
 using namespace Guikachu;
@@ -30,14 +29,7 @@ ID::ID (notify_signal_t &notify_signal,
 
 void ID::set_val (const string& value_)
 {
-    string real_id = value_;
-
-    for (string::iterator i = real_id.begin ();
-	 i != real_id.end (); i++)
-    {
-	if (*i == ' ')
-	    *i = '_';
-    }
+    string real_id = ResourceManager::validate_id (value_);
 
     if (ResourceManager::rename_resource (value, real_id))
 	Property<string>::set_val (real_id);
