@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.13 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.14 2001/11/02 18:20:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,11 +21,14 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+/* Having to include these for just open()/close() and *time() sure sucks */
 #include <fstream>
 #include <time.h>
-#include <gnome-xml/parser.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
 
-#include "mainwin.h"
 #include "storage.h"
 
 using namespace Guikachu;
@@ -49,30 +52,22 @@ void ResourceManager::reset ()
     dirty = false;
 }
 
-bool ResourceManager::load (const string& filename)
+ResourceManager::IOResult ResourceManager::load (const string& filename)
 {
     Storage storage;
 
+    int fd = open (filename.c_str (), O_RDONLY);
+    if (fd == -1)
+	return IO_NOTFOUND;
+    close (fd);
+	
+    
     if (!storage.load (filename))
-    {
-	gchar *buffer = g_strdup_printf (_("Unable to open `%s'"),
-					 g_basename (filename.c_str ()));
-	GUI::show_error (buffer);
-	g_free (buffer);
-
-	return false;
-    }
+	return IO_INVALID;
 	
     StorageNode root_node = storage.get_root ();
     if (root_node.name () != "guikachu")
-    {
-	gchar *buffer = g_strdup_printf (_("Unable to open `%s': "
-					   "Not a valid Guikachu document"),
-					 g_basename (filename.c_str ()));
-	GUI::show_error (buffer);
-	g_free (buffer);
-        return false;
-    }
+        return IO_INVALID;
 
     /*
      * Walk the tree
@@ -89,7 +84,8 @@ bool ResourceManager::load (const string& filename)
     }
     
     dirty = false;
-    return true;
+
+    return IO_OK;
 }
 
 Resources::Resource* ResourceManager::load_resource (StorageNode &node)
@@ -124,7 +120,7 @@ Resources::Resource* ResourceManager::load_resource (StorageNode &node)
     return resource;
 }
 
-void ResourceManager::save (const string& filename)
+ResourceManager::IOResult ResourceManager::save (const string& filename)
 {
     Storage     storage;
     StorageNode root = storage.create_root ("guikachu");
@@ -169,6 +165,8 @@ void ResourceManager::save (const string& filename)
     storage.save (filename);
 
     dirty = false;
+
+    return IO_OK;
 }
 
 void ResourceManager::export_rcp (const string& filename)
