@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.9 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.10 2001/11/02 18:20:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,6 +41,7 @@ namespace Guikachu
 	static set<string_case> id_set;
 	static bool dirty;
 	static Resources::Application *app;
+
     public:
 	static Resources::Resource* create_resource (Resources::Type  type,
 						     const string    &id = "");
@@ -63,10 +64,17 @@ namespace Guikachu
 	static SigC::Signal1<void, Resources::Resource*> resource_removed;
 	
 	// Persistance
+	enum IOResult
+	{
+	    IO_OK,
+	    IO_NOTFOUND,
+	    IO_INVALID
+	};
+	
 	static void reset ();
 	static bool is_dirty ();
-	static bool load (const string &filename);
-	static void save (const string &filename);
+	static IOResult load (const string &filename);
+	static IOResult save (const string &filename);
 	static void export_rcp (const string &filename); 
 
     private:
