@@ -1,4 +1,4 @@
-//$Id: string-res.cc,v 1.8 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: string-res.cc,v 1.9 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -17,8 +17,7 @@
  */
 
 #include "string-res.h"
-
-#include <gnome-xml/xmlmemory.h>
+#include "string-win.h"
 
 using namespace Guikachu;
 
