@@ -1,4 +1,4 @@
-//$Id: string-res.h,v 1.6 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: string-res.h,v 1.7 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,10 +28,14 @@ namespace Guikachu
 }
 
 #include "resource.h"
-#include "string-win.h"
 
 namespace Guikachu
 {
+    namespace GUI
+    {
+	class StringWindow;
+    }
+    
     namespace Resources
     {
 	class String: public Resource
