@@ -1,4 +1,4 @@
-//$Id: entry.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: entry.cc,v 1.3 2001/10/28 14:08:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,8 +34,8 @@ Entry::Entry (bool live_update,
     {
 	changed.connect (slot (this, &Entry::changed_cb));
     } else {
-	activate.connect (slot (this, &Entry::activate_cb));
-	Slot0<int> activate_slot = retbind (slot (this, &Entry::activate_cb), 0);
+	activate.connect (slot (this, &Entry::changed_cb));
+	Slot0<int> activate_slot = retbind (slot (this, &Entry::changed_cb), 0);
 	focus_out_event.connect (SigC::hide <int, GdkEventFocus*> (activate_slot));
     }
 
@@ -43,19 +43,19 @@ Entry::Entry (bool live_update,
     update ();
 }
 
-void Entry::activate_cb ()
-{
-    if (!update_block)
-	property = get_text ();
-}
-
 void Entry::changed_cb ()
 {
     if (update_block)
         return;
 
+    update_block = true;
+    
     int saved_pos = get_position ();
     property = get_text ();
+
+    update_block = false;
+    
+    update ();
     set_position (saved_pos);
 }
 
