@@ -1,4 +1,4 @@
-//$Id: propertytable.cc,v 1.7 2001/09/16 13:06:08 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.cc,v 1.8 2001/11/03 19:18:32 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,6 +25,7 @@
 #include <gtk--/alignment.h>
 #include <gtk--/window.h>
 #include <gtk--/togglebutton.h>
+#include <gtk/gtknotebook.h>
 
 using namespace Guikachu::GUI;
 
@@ -169,7 +170,47 @@ void PropertyTable::parent_changed_cb (Gtk::Widget *old_parent)
 	    old_window->remove_accel_group (*accel_group);
     }
 
-    Gtk::Window *new_window = get_toplevel ();
-    if (new_window && GTK_IS_WINDOW (new_window->gtkobj ()))
-	new_window->add_accel_group (*accel_group);
+    GtkWidget *new_parent = gtk_widget_get_toplevel (GTK_WIDGET (gtkobj ()));
+
+    // if new_parent is not a GtkWindow, it means our parent is an
+    // intermediate container not yet added to a window
+
+    if (new_parent && new_parent != GTK_WIDGET (gtkobj ()))
+    {
+	if (GTK_IS_WINDOW (new_parent))
+	    Gtk::wrap (GTK_WINDOW (new_parent))->add_accel_group (*accel_group);
+	else
+	{
+	    Gtk::Widget *new_parent_w = Gtk::wrap (new_parent);
+	    
+	    new_parent_w->parent_changed.connect (
+		SigC::bind (SigC::slot (this, &PropertyTable::parent_changed_delegated_cb),
+			    new_parent_w));
+	}
+    }
+}
+
+void PropertyTable::parent_changed_delegated_cb (Gtk::Widget *old_parent,
+						 Gtk::Widget *widget)
+{
+    if (old_parent && old_parent != widget)
+    {
+	Gtk::Window *old_window = old_parent->get_toplevel ();
+	if (old_window && GTK_IS_WINDOW (old_window->gtkobj ()))
+	    old_window->remove_accel_group (*accel_group);
+    }
+
+    GtkWidget *new_parent = gtk_widget_get_toplevel (GTK_WIDGET (widget->gtkobj ()));
+
+    // if new_parent is not a GtkWindow, it means our parent is an
+    // intermediate container not yet added to a window
+
+    if (new_parent && new_parent != GTK_WIDGET (widget->gtkobj ()))
+    {
+	if (GTK_IS_WINDOW (new_parent))
+	    Gtk::wrap (GTK_WINDOW (new_parent))->add_accel_group (*accel_group);
+	else
+	    Gtk::wrap (GTK_WIDGET (new_parent))->parent_changed.connect (
+		SigC::slot (this, &PropertyTable::parent_changed_cb));
+    }
 }
