@@ -1,4 +1,4 @@
-//$Id: propertytable.h,v 1.4 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.h,v 1.5 2001/11/03 19:18:32 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,6 +50,8 @@ namespace Guikachu
 				       Gtk::Widget  &control,
 				       const string &tooltip);
 	    void parent_changed_cb (Gtk::Widget *old_parent);
+	    void parent_changed_delegated_cb (Gtk::Widget *old_parent,
+					      Gtk::Widget *widget);
 	};
     }
 }
