@@ -1,4 +1,4 @@
-//$Id: string-list.cc,v 1.5 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-
+//$Id: string-list.cc,v 1.7 2001/11/03 20:18:27 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,23 +29,25 @@ using namespace Guikachu::GUI;
 
 StringList::StringList (Property<value_t> &property_):
     Gtk::HBox (false, 5),
-    property (property_),	 
+    property (property_),
+    buttons (new Gtk::VButtonBox),
     update_block (false)
 {
     using namespace SigC;
 
+    set_border_width (5);
+    
     /* Left pane: list of strings and an entry to edit the current
      * item */
     Gtk::VBox *vbox = new Gtk::VBox (false, 5);
     add (*manage (vbox));
     
     /* The List holding the strings */
-    list_widget = new Gtk::List;
-    list_widget->set_selection_mode (GTK_SELECTION_BROWSE);
-    list_widget->selection_changed.connect (slot (this, &StringList::selection_cb));
+    list_widget.set_selection_mode (GTK_SELECTION_BROWSE);
+    list_widget.selection_changed.connect (slot (this, &StringList::selection_cb));
     
     Gtk::ScrolledWindow *scrollwin = new Gtk::ScrolledWindow;
-    scrollwin->add_with_viewport (*manage (list_widget));
+    scrollwin->add_with_viewport (list_widget);
     scrollwin->set_policy (GTK_POLICY_AUTOMATIC,
 			   GTK_POLICY_AUTOMATIC);
     
@@ -53,10 +55,9 @@ StringList::StringList (Property<value_t> &property_):
     vbox->add (*manage (scrollwin));
 
     /* The Entry for editing items */
-    entry = new Gtk::Entry;
-    entry->activate.connect (slot (this, &StringList::entry_activate_cb));
+    entry.activate.connect (slot (this, &StringList::entry_activate_cb));
     
-    vbox->pack_start (*manage (entry), false, false);
+    vbox->pack_start (entry, false, false);
     
     /* The modifier buttons */
     btnAdd  = Gtk::wrap (GTK_BUTTON (
@@ -77,7 +78,6 @@ StringList::StringList (Property<value_t> &property_):
     btnDown = new Gnome::Stock::Button (GNOME_STOCK_BUTTON_DOWN);
     btnDown->clicked.connect (slot (this, &StringList::button_down_cb));
     
-    Gtk::VButtonBox *buttons = new Gtk::VButtonBox;
     buttons->add (*manage (btnUp));
     buttons->add (*manage (btnDown));
     buttons->add (*manage (btnRemove));
@@ -90,74 +90,114 @@ StringList::StringList (Property<value_t> &property_):
     selection_cb ();
 }
 
+void StringList::add_button (Gtk::Widget &button)
+{
+    Gtk::Box::BoxList &box_list = buttons->children ();
+    box_list.insert (box_list.find (*btnRemove), button);
+}
+
+void StringList::clear_list ()
+{
+    list_widget.items ().clear ();
+}
+
+void StringList::add_to_list (int           index,
+			      const string &label)
+{
+    Gtk::ListItem *item = new Gtk::ListItem (label);
+    item->show ();
+    item->set_user_data (GUINT_TO_POINTER (index));
+    
+    list_widget.items ().push_back (*manage (item));
+}
+
 void StringList::update ()
 {
     update_block = true;
 
-    list_widget->items ().clear ();
+    clear_list ();
     
     const value_t &curr_val = property;
     unsigned int index = 0;
     for (value_t::const_iterator i = curr_val.begin ();
 	 i != curr_val.end (); i++, index++)
-    {
-	Gtk::ListItem *item = new Gtk::ListItem (*i);
-	item->show ();
-	item->set_user_data (GUINT_TO_POINTER (index));
-	
-	list_widget->items ().push_back (*manage (item));
-    }
+	add_to_list (index, *i);
     
     update_block = false;
 }
 
 void StringList::selection_cb ()
 {
-    Gtk::List::SelectionList sel_list = list_widget->selection ();
-	
+    Gtk::List::SelectionList sel_list = list_widget.selection ();
+
     if (!sel_list.size ())
     {
 	
-	btnRemove->set_sensitive (false);
 	btnUp->set_sensitive (false);
 	btnDown->set_sensitive (false);
 
-	entry->set_text ("");
+	Gtk::Box::BoxList::iterator begin = ++buttons->children ().find (*btnDown);
+	Gtk::Box::BoxList::iterator end = buttons->children ().find (*btnAdd);
+	for (Gtk::Box::BoxList::iterator i = begin; i != end; i++)
+	    (*i)->get_widget ()->set_sensitive (false);
+	
+	entry.set_text ("");
 	
     } else {
+
+	if (update_block)
+	    return;
 	
 	g_return_if_fail (sel_list.size() == 1);
 
 	unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin()))->get_user_data ());
-
-	btnRemove->set_sensitive (true);
+	
 	btnUp->set_sensitive ((index > 0));
 	btnDown->set_sensitive ((index < (property ().size () - 1)));
 
-	entry->set_text (property ()[index]);
+	Gtk::Box::BoxList::iterator begin = ++buttons->children ().find (*btnDown);
+	Gtk::Box::BoxList::iterator end = buttons->children ().find (*btnAdd);
+	for (Gtk::Box::BoxList::iterator i = begin; i != end; i++)
+	    (*i)->get_widget ()->set_sensitive (true);
+
+	/*
+	cerr << index << endl;
+	const value_t &vec = property;
+	if (index > vec.size ())
+	    return;
+	*/
+	    
+//	const string current_text = vec[index];
+	entry.set_text (property ()[index]);
     }
 }
 
+unsigned int StringList::get_selected_row ()
+{
+    g_return_val_if_fail (list_widget.selection ().size () == 1, 0);
+
+    Gtk::List::SelectionList::iterator sel = list_widget.selection ().begin ();  
+    return GPOINTER_TO_UINT ((*sel)->get_user_data ());
+}
+
 void StringList::button_remove_cb ()
 {
-    g_return_if_fail (list_widget->selection ().size () == 1);
-
-    Gtk::List::SelectionList::iterator sel = list_widget->selection ().begin ();  
-    unsigned int index = GPOINTER_TO_UINT ((*sel)->get_user_data ());
-
+    unsigned int index = get_selected_row ();
     value_t val = property;
     val.erase (val.begin () + index);
     property = val;
 
-    list_widget->select_item (index);
+    index = MIN (index, property ().size () - 1);
+
+    item_removed.emit (index);
+    
+    list_widget.unselect_item (index);
+    list_widget.select_item (index);
 }
 
 void StringList::button_up_cb ()
 {
-    Gtk::List::SelectionList sel_list = list_widget->selection ();
-    g_return_if_fail (sel_list.size () == 1);
-
-    unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin ()))->get_user_data ());
+    unsigned int index = get_selected_row ();
     g_return_if_fail (index != 0);
 
     value_t val = property;
@@ -165,17 +205,17 @@ void StringList::button_up_cb ()
     value_t::iterator prev = curr - 1;
     iter_swap (curr, prev);
     property = val;
-
-    list_widget->select_item (index - 1);
+    
+    up.emit (index);
+    
+    list_widget.unselect_item (index - 1);
+    list_widget.select_item (index - 1);
 }
 
 void StringList::button_down_cb ()
 {
-    Gtk::List::SelectionList sel_list = list_widget->selection ();
-    g_return_if_fail (sel_list.size () == 1);
-
-    unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin ()))->get_user_data ());
-    g_return_if_fail (index < list_widget->items ().size () - 1);
+    unsigned int index = get_selected_row ();
+    g_return_if_fail (index < list_widget.items ().size () - 1);
 
     value_t val = property;
     value_t::iterator curr = val.begin () + index;
@@ -183,38 +223,55 @@ void StringList::button_down_cb ()
     iter_swap (curr, next);
     property = val;
 
-    list_widget->select_item (index + 1);
+    down.emit (index);
+
+    list_widget.unselect_item (index + 1);
+    list_widget.select_item (index + 1);
 }
 
 void StringList::button_add_cb ()
 {
-    int index = 0;
+    unsigned int index = 0;
     
-    if (list_widget->selection ().size ())
-	index = GPOINTER_TO_UINT ((*(list_widget->selection ().begin ()))->get_user_data ());
+    if (list_widget.selection ().size ())
+	index = GPOINTER_TO_UINT ((*(list_widget.selection ().begin ()))->get_user_data ());
+
+    string item_text = entry.get_text ();
+    if (item_text == "")
+	return;
     
     value_t curr_val = property;
-    curr_val.push_back (entry->get_text ());
+    value_t::iterator pos = curr_val.begin () + index + 1;
+    if (index == curr_val.size ())
+	curr_val.push_back (item_text);
+    else
+	curr_val.insert (pos, item_text);
     property = curr_val;
 
-    if (index)
-	list_widget->select_item (index);
+    item_added.emit (index + 1);
+    
+    list_widget.select_item (index + 1);
 }
 
 void StringList::entry_activate_cb ()
 {
-    if (!list_widget->selection ().size ())
+    if (!list_widget.selection ().size ())
     {
 	button_add_cb ();
 	return;
     }
-    
-    string new_text = entry->get_text ();
-    unsigned int index = GPOINTER_TO_UINT ((*(list_widget->selection ().begin ()))->get_user_data ());
+
+    string new_text = entry.get_text ();
+    if (new_text == "")
+    {
+	return;
+    }
+	
+    unsigned int index = get_selected_row ();
     value_t val = property;
 
     val[index] = new_text;
     property = val;
 
-    list_widget->select_item (index);
+    list_widget.select_item (index);
 }
