@@ -1,4 +1,4 @@
-//$Id: string-list.h,v 1.4 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: string-list.h,v 1.6 2001/11/03 20:18:27 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,19 +34,35 @@ namespace Guikachu
     {
 	class StringList: public Gtk::HBox
 	{
+	protected:
 	    typedef vector<string> value_t;
-
 	    Property<value_t> &property;
 
-	    Gtk::List   *list_widget;
+	    Gtk::List    list_widget;
+	    
+	private:
 	    Gtk::Button *btnAdd, *btnUp, *btnDown, *btnRemove;
-	    Gtk::Entry  *entry;
+	    Gtk::Entry   entry;
+	    Gtk::Box    *buttons;
 	    
 	public:
 	    StringList (Property<value_t> &property);
-	private:
+
+	protected:
+	    unsigned int get_selected_row ();
+	    
 	    bool update_block;
-	    void update ();
+	    void add_button (Gtk::Widget &widget);
+	    void clear_list ();
+	    void add_to_list (int index, const string &label);
+
+	    SigC::Signal1<void, unsigned int> item_added;
+	    SigC::Signal1<void, unsigned int> item_removed;
+	    SigC::Signal1<void, unsigned int> up;   /* Argument is the _old_ index */
+	    SigC::Signal1<void, unsigned int> down; /* Argument is the _old_ index */
+	    
+	private:
+	    virtual void update ();
 
 	    void selection_cb ();
 	    
