@@ -1,4 +1,4 @@
-//$Id: text.cc,v 1.1 2001/08/19 13:18:45 cactus Exp $ -*- c++ -*-
+//$Id: text.cc,v 1.2 2001/11/01 13:20:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,7 +41,12 @@ void TextArea::changed_cb ()
         return;
 
     int saved_pos = get_position ();
-    text = get_chars (0, get_length ());
+
+    gchar *text_chars = gtk_editable_get_chars (
+	GTK_EDITABLE (gtkobj ()), 0, get_length ());
+    text = text_chars;
+    g_free (text_chars);
+    
     gtk_editable_set_position (GTK_EDITABLE (gtkobj ()), saved_pos);
 }
 
